The Pandeia engine is a 'simulation-hybrid' exposure time calculation engine that performs calculations on two-dimensional astronomical scenes created by the user. It uses a pixel-based 3D approach, modeling both the spatial and wavelength dimensions using realistic PSFs for each instrument mode, and handles saturation, correlated read noise, and inter-pixel capacitance. It supports both the James Webb Space Telescope and the Wide-field Imager mode of the Nancy Grace Roman Space Telescope.

Installation and setup instructions (including a required data package) for the Pandeia engine can be found at this Space Telescope Science Institute page: https://outerspace.stsci.edu/display/PEN/Pandeia+Engine+News

See also this page for James Webb Space Telescope (JWST)-specific installation instructions:
https://jwst-docs.stsci.edu/jwst-exposure-time-calculator-overview/jwst-etc-pandeia-engine-tutorial/installing-pandeia

A usage guide (JWST-focused) for the Pandeia engine can be found here: https://jwst-docs.stsci.edu/jwst-exposure-time-calculator-overview/jwst-etc-pandeia-engine-tutorial

Any questions about the Pandeia engine should be directed to the JWST Help Desk at https://stsci.service-now.com/jwst.
